![PyPI](https://img.shields.io/pypi/v/sigpytch)
# SIGPytch
Quantitative models and metrics used in the SIG at UCSD quarterly stock pitches.

## Table of Contents
- [Installation](#installation)
- [Requirements](#requirements)
- [Metrics](#metrics)
- [Models](#models)
- [Contributing](#contributing)

## Installation
```
pip install sigpytch
```

## Requirements
This library requires the following dependencies:
  - [pandas](https://pandas.pydata.org/getting_started)>=1.4.0
  - [scikit-learn](https://scikit-learn.org/stable/install)>=1.1.13
  - [tensorflow](https://www.tensorflow.org/install)>=2.11.0

## Metrics
### `sigpytch.metrics`
  - `rolling_sharpe`
  
## Models
### `sigpytch.forecasters`
  - `LSTMForecaster`
  
## Contributing
Reach out to Pranay to be added as a contributor to this repository.
